import * as i0 from '@angular/core';
import { InjectionToken, Pipe, Optional, Inject, NgModule } from '@angular/core';

/**
 * Set the locale(s) for all Intl Pipes. If not specified, the user language specified in the browser will be used. If
 * specified, it needs to be a string with a BCP 47 language tag, or an array of such strings.
 */
const INTL_LOCALES = new InjectionToken('IntlLocales');

const INTL_DATE_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlDatePipeDefaultOptions');

class IntlDatePipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const date = new Date(value);
        if (isNaN(date.getTime())) {
            return null;
        }
        try {
            return new Intl.DateTimeFormat((_a = this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign({}, this.defaultOptions), options)).format(date);
        }
        catch (e) {
            console.warn('Error while parsing the date', e);
            return date.toString();
        }
    }
}
IntlDatePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: IntlDatePipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_DATE_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlDatePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: IntlDatePipe, isStandalone: true, name: "intlDate" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: IntlDatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlDate',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_DATE_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

class IntlModule {
}
IntlModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: IntlModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
IntlModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: IntlModule, imports: [IntlDatePipe], exports: [IntlDatePipe] });
IntlModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: IntlModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: IntlModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        IntlDatePipe,
                    ],
                    exports: [
                        IntlDatePipe,
                    ],
                }]
        }] });

/*
 * Public API Surface of angular-ecmascript-intl
 */

/**
 * Generated bundle index. Do not edit.
 */

export { INTL_LOCALES, IntlDatePipe, IntlModule };
//# sourceMappingURL=angular-ecmascript-intl.mjs.map
